@@ -67,7 +67,7 @@ def revolve(
       passed will be a full revolution (`angle = 2*pi`)
     cap
       If not a full revolution (`0.0 < angle < 2 * pi`)
-      and cap is True attempt to add a tesselated cap.
+      and cap is True attempt to add a tessellated cap.
     sections
       Number of sections result should have
       If not specified default is 32 per revolution
@@ -208,7 +208,11 @@ def revolve(
 
 
 def extrude_polygon(
-    polygon: "Polygon", height: Number, transform: Optional[ArrayLike] = None, **kwargs
+    polygon: "Polygon",
+    height: Number,
+    transform: Optional[ArrayLike] = None,
+    mid_plane: bool = False,
+    **kwargs,
 ) -> Trimesh:
     """
     Extrude a 2D shapely polygon into a 3D mesh
@@ -233,6 +237,15 @@ def extrude_polygon(
     """
     # create a triangulation from the polygon
     vertices, faces = triangulate_polygon(polygon, **kwargs)
+
+    if mid_plane:
+        translation = np.eye(4)
+        translation[2, 3] = abs(float(height)) / -2.0
+        if transform is None:
+            transform = translation
+        else:
+            transform = np.dot(transform, translation)
+
     # extrude that triangulation along Z
     mesh = extrude_triangulation(
         vertices=vertices, faces=faces, height=height, transform=transform, **kwargs
@@ -849,7 +862,7 @@ def icosahedron(**kwargs) -> Trimesh:
 
 def icosphere(subdivisions: Integer = 3, radius: Number = 1.0, **kwargs):
     """
-    Create an isophere centered at the origin.
+    Create an icosphere centered at the origin.
 
     Parameters
     ----------
@@ -960,7 +973,8 @@ def capsule(
     radius: Number = 1.0,
     count: Optional[ArrayLike] = None,
     transform: Optional[ArrayLike] = None,
-):
+    **kwargs,
+) -> Trimesh:
     """
     Create a mesh of a capsule, or a cylinder with hemispheric ends.
 
@@ -1005,6 +1019,7 @@ def capsule(
         sections=count[1],
         transform=transform,
         metadata={"shape": "capsule", "height": height, "radius": radius},
+        **kwargs,
     )
 
 
@@ -1021,9 +1036,9 @@ def cone(
     Parameters
     ----------
     radius : float
-      The radius of the cylinder
+      The radius of the cone at the widest part.
     height : float
-      The height of the cylinder
+      The height of the cone.
     sections : int or None
       How many pie wedges per revolution
     transform : (4, 4) float or None
@@ -1356,7 +1371,7 @@ def camera_marker(
 
     # combine the points into the vertices of an FOV visualization
     points = np.array(
-        [(0, 0, 0), (-x, -y, z), (x, -y, z), (x, y, z), (-x, y, z)], dtype=float
+        [(0, 0, 0), (-x, -y, -z), (x, -y, -z), (x, y, -z), (-x, y, -z)], dtype=float
     )
 
     # create line segments for the FOV visualization
